@@ -1,11 +1,16 @@
 from .robot import Robot
+import requests
+import pathlib
 
+localhost_pem = pathlib.Path(__file__).with_name("file.pem")
+certificate_url = 'https://coderz-public-files.s3.amazonaws.com/certificates/local.gocoderz.com/file.pem'
 conf = {
     "communication": {
         "communication_manager_type": "ide"
     }
 }
 
+
 class Server():
     _is_server_started = False
 
@@ -17,6 +22,9 @@ class Server():
             print('Server already started')
             return
 
+        certificate_obj = requests.get(certificate_url)
+        with open(localhost_pem, 'w') as pem_file:
+            pem_file.write(certificate_obj.text)
         Server._robot = Robot(conf)
         Server._is_server_started = True
         Server._robot.print_manual()
@@ -31,12 +39,12 @@ class Server():
 
         comm_mngr.stop()
 
-        Server._robot.get_thread().join()
+        Server._robot.get_thread().join(1)
 
         Server._is_server_started = False
         Server._robot = None
 
-        print('Server terminated')
+        print('Server stopped')
 
     @staticmethod
     def get_robot():
